# Check Standard Report for CTN202

This device has been measured 52 times from 1985-11-14 09:55:04 to 1991-07-23 13:09:00

## Downloads

Historical_Database.txt | csv | xlsx
Mean_Database.txt | csv | xlsx
Device_History.txt | csv | xlsx

## The Complete History of CTN202

Figure 1. Every measurement of CTN202 currently in the database.

## The last 5 measurements of CTN202 compared with the historical database and mean.

Figure 2. Last 5 measurements of CTN202 compared with historical database and mean